/*
 *              kPPP: A pppd Front End for the KDE project
 *
 * $Id: docking.h,v 1.9 2001/03/25 04:13:24 tibirna Exp $
 *
 *              Copyright (C) 1997 Bernd Johannes Wuebben
 *                      wuebben@math.cornell.edu
 *
 * This file was contributed by Harri Porten <porten@tu-harburg.de>
 * Latest changes (dynamic tooltips) by Cristian Tibirna <tibirna@kde.org>
 *
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this program; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef _DOCKING_H_
#define _DOCKING_H_

#include <stdio.h>
#include <qapplication.h>
#include <qpixmap.h>
#include <qtimer.h>
#include <qpopupmenu.h>
#include <qpoint.h>
#include <kdockwindow.h>

extern int      ibytes;
extern int      obytes;

class KSCD;

class DockWidget : public KSystemTray {

  Q_OBJECT

public:
  DockWidget( KSCD* parent, const char *name=0);
  ~DockWidget();

public slots:
  void setToolTip(const QString& text);

private:
  QString tip;

};

#endif



